==> jupyterlab-js-logs-0.2.4.tar.gz: jupyterlab-js-logs-0.2.4/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.2.4

([Full Changelog](https://github.com/QuantStack/jupyterlab-js-logs/compare/v0.2.3...62cef996ed0c8434147907aa3a8bdb7bf6ffc9a6))

### Maintenance and upkeep improvements

- Set name as jupyterlab-js-logs [#17](https://github.com/QuantStack/jupyterlab-js-logs/pull/17) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Update Binder link to point to the `main` branch [#16](https://github.com/QuantStack/jupyterlab-js-logs/pull/16) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/QuantStack/jupyterlab-js-logs/graphs/contributors?from=2021-09-14&to=2021-09-15&type=c))

[@jtpio](https://github.com/search?q=repo%3AQuantStack%2Fjupyterlab-js-logs+involves%3Ajtpio+updated%3A2021-09-14..2021-09-15&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.2.3

([Full Changelog](https://github.com/QuantStack/jupyterlab-js-logs/compare/0.2.2...14e59dc4e5d15a3a6246d8bb1967e18fddac9b10))

### Bugs fixed

- Remove circular references when stringifying an object [#11](https://github.com/QuantStack/jupyterlab-js-logs/pull/11) ([@hbcarlos](https://github.com/hbcarlos))

### Maintenance and upkeep improvements

- Add `publishConfig` to `package.json` [#13](https://github.com/QuantStack/jupyterlab-js-logs/pull/13) ([@jtpio](https://github.com/jtpio))
- Add github action to check release [#12](https://github.com/QuantStack/jupyterlab-js-logs/pull/12) ([@hbcarlos](https://github.com/hbcarlos))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/QuantStack/jupyterlab-js-logs/graphs/contributors?from=2021-08-06&to=2021-09-14&type=c))

[@hbcarlos](https://github.com/search?q=repo%3AQuantStack%2Fjupyterlab-js-logs+involves%3Ahbcarlos+updated%3A2021-08-06..2021-09-14&type=Issues) | [@jtpio](https://github.com/search?q=repo%3AQuantStack%2Fjupyterlab-js-logs+involves%3Ajtpio+updated%3A2021-08-06..2021-09-14&type=Issues)

## 0.2.2

==> jupyterlab-js-logs-0.2.5.tar.gz: jupyterlab-js-logs-0.2.5/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.2.5

([Full Changelog](https://github.com/QuantStack/jupyterlab-js-logs/compare/v0.2.4...2b893318a9ee85a3c649fcb92f1ded9ba732a00d))

### Merged PRs

- Build js in prod mode for the release [#20](https://github.com/QuantStack/jupyterlab-js-logs/pull/20) ([@hbcarlos](https://github.com/hbcarlos))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/QuantStack/jupyterlab-js-logs/graphs/contributors?from=2021-09-15&to=2022-01-21&type=c))

[@hbcarlos](https://github.com/search?q=repo%3AQuantStack%2Fjupyterlab-js-logs+involves%3Ahbcarlos+updated%3A2021-09-15..2022-01-21&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.2.4

([Full Changelog](https://github.com/QuantStack/jupyterlab-js-logs/compare/v0.2.3...62cef996ed0c8434147907aa3a8bdb7bf6ffc9a6))

### Maintenance and upkeep improvements

- Set name as jupyterlab-js-logs [#17](https://github.com/QuantStack/jupyterlab-js-logs/pull/17) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Update Binder link to point to the `main` branch [#16](https://github.com/QuantStack/jupyterlab-js-logs/pull/16) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/QuantStack/jupyterlab-js-logs/graphs/contributors?from=2021-09-14&to=2021-09-15&type=c))

[@jtpio](https://github.com/search?q=repo%3AQuantStack%2Fjupyterlab-js-logs+involves%3Ajtpio+updated%3A2021-09-14..2021-09-15&type=Issues)

## 0.2.3

([Full Changelog](https://github.com/QuantStack/jupyterlab-js-logs/compare/0.2.2...14e59dc4e5d15a3a6246d8bb1967e18fddac9b10))

### Bugs fixed

- Remove circular references when stringifying an object [#11](https://github.com/QuantStack/jupyterlab-js-logs/pull/11) ([@hbcarlos](https://github.com/hbcarlos))

### Maintenance and upkeep improvements

- Add `publishConfig` to `package.json` [#13](https://github.com/QuantStack/jupyterlab-js-logs/pull/13) ([@jtpio](https://github.com/jtpio))
- Add github action to check release [#12](https://github.com/QuantStack/jupyterlab-js-logs/pull/12) ([@hbcarlos](https://github.com/hbcarlos))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/QuantStack/jupyterlab-js-logs/graphs/contributors?from=2021-08-06&to=2021-09-14&type=c))

[@hbcarlos](https://github.com/search?q=repo%3AQuantStack%2Fjupyterlab-js-logs+involves%3Ahbcarlos+updated%3A2021-08-06..2021-09-14&type=Issues) | [@jtpio](https://github.com/search?q=repo%3AQuantStack%2Fjupyterlab-js-logs+involves%3Ajtpio+updated%3A2021-08-06..2021-09-14&type=Issues)

## 0.2.2
